@@ -18,14 +18,14 @@ arr <- function(from, to=0) {
 display.locations <- function(g, main="",tectum=TRUE,
                               xmin=min(g$axon.positions[,1]), xmax=max(g$axon.positions[,1]), 
                               ymin=min(g$axon.positions[,2]), ymax=max(g$axon.positions[,2]),
-                              label=TRUE,
+                              label=FALSE,
                               asp=1,
                               ...) {
   ## show the active tectal or retinal locations
 
   if (tectum==TRUE) {
     tect.pos <- g$tect.positions[which(g$tect.status==1),]
-    plot(tect.pos, pch=4, col="grey", cex=2, xlab="x", ylab="y", main=main,
+    plot(tect.pos, pch=4, col="grey", cex=0.3, xlab="x", ylab="y", main=main,
          axes=F, frame.plot=T, ...)
     ##axis(1,at=c(0,1),labels=c("Caudal","Rostral"),cex=2.5)
     axis(1,at=c(0,1),labels=c("Anterior","Posterior"),cex=2.5)
@@ -118,6 +118,8 @@ display.mesh <- function(g, indices = 1:g$axons,
               xmin,xmax,ymin,ymax) )
     }
   }
+  ## After drawing the mesh, keep track of the centre-of-mass for each RGC target.
+  g$com <- p
 }
 
 display.potential <- function(axon) {
@@ -560,13 +562,24 @@ write.connections <- function(g, opfile) {
   stopifnot(isTRUE(all.equal(colSums(conn), rep(16, g$axons))))
 }
 
-display.map <- function(g, main=NULL) {
+write.targets <- function(g, opfile) {
+  ## Similar to write.connections, but just output one row per RGC listing
+  ## the targets of that RGC.  If the RGC makes contact with the same tectal
+  ## cell multiple times, it is listed multiple times.
+  conn <- t(with(g, sapply(1:axons, function(i) 
+                         connections[which(cone.axons == i)])))
+  
+  stopifnot(ncol(conn) == g$nterm)
+  write.table(conn, file=opfile, sep=',', row.names=F, col.names=F)
+}
+
+display.map <- function(g, main=NULL, label=FALSE) {
 
   if(is.null(main)) {
     main <- sprintf("epoch %d", g$epoch)
   }
 
-  display.locations(g, main=main)
+  display.locations(g, main=main, label=label)
   display.mesh(g)
 }
 
